Transforms#
Particle transforms scale each particle’s foot before the footprint is
made (see Particle Weighting (Transforms)). A transform is any object with an
apply(particles, context) method. The built-ins are pydantic models,
and their fields are their config.yaml keys.
Interface#
Interface for a transform: any object with |
|
Information about the simulation a transform is applied for. |
Built-in transforms#
Transform that weights each particle's |
|
Transform that weights each particle by its share of the column's air mass. |
|
Transform that decays each particle's |
Averaging-kernel tables#
Return a table of averaging kernels, one per receptor, for |
Science helpers#
Return each particle's value of |
|
Return each particle's release pressure and pressure weight. |
|
Return the averaging kernel at each particle's release coordinate. |
Loading and dumping#
Return the transform for one config entry. |
|
Return the config mapping for one transform, the inverse of |
|
Apply |