Transforms#
Particle transforms rescale each particle’s foot before a footprint is
rasterized (see Particle Weighting (Transforms)). A transform is any object with
apply(particles, context); the built-ins are pydantic models whose fields
are their config.yaml keys.
Interface#
Anything with |
|
What a transform may know about the footprint it is applied for. |
Built-in transforms#
Weight each particle's |
|
Weight each particle by the fraction of the column's air mass it represents. |
|
Decay each particle's |
|
A transform whose class could not be imported. |
Science helpers#
Return each particle's release value of |
|
Derive each particle's release pressure and pressure weight. |
|
Interpolate an averaging kernel to each row's particle release coordinate. |
Loading and dumping#
Return a transform for one config entry. |
|
Return the config mapping for one transform (inverse of |
|
Apply transforms in order; returns particles itself when there are none. |